package com.ruoyi.szxc.service.impl;

import com.ruoyi.szxc.domain.SzxcJmTag;
import com.ruoyi.szxc.mapper.SzxcJmTagMapper;
import com.ruoyi.szxc.service.ISzxcJmTagService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * 居民标签关联Service业务层处理
 *
 * @author hs
 * @date 2024-03-30
 */
@Service
public class SzxcJmTagServiceImpl implements ISzxcJmTagService
{
    @Autowired
    private SzxcJmTagMapper szxcJmTagMapper;

    /**
     * 查询居民标签关联
     *
     * @param id 居民标签关联主键
     * @return 居民标签关联
     */
    @Override
    public SzxcJmTag selectSzxcJmTagById(Long id)
    {
        return szxcJmTagMapper.selectSzxcJmTagById(id);
    }

    /**
     * 查询居民标签关联列表
     *
     * @param szxcJmTag 居民标签关联
     * @return 居民标签关联
     */
    @Override
    public List<SzxcJmTag> selectSzxcJmTagList(SzxcJmTag szxcJmTag)
    {
        return szxcJmTagMapper.selectSzxcJmTagList(szxcJmTag);
    }

    /**
     * 新增居民标签关联
     *
     * @param szxcJmTag 居民标签关联
     * @return 结果
     */
    @Override
    public int insertSzxcJmTag(SzxcJmTag szxcJmTag)
    {
        return szxcJmTagMapper.insertSzxcJmTag(szxcJmTag);
    }

    /**
     * 新增、修改居民标签集合关联
     * @param szxcJmTags
     * @return
     */
    @Override
    @Transactional
    public int insertSzxcJmTags(List<SzxcJmTag> szxcJmTags) {
        int result=1;
        try {
            if(szxcJmTags!=null&&szxcJmTags.size()>0){
                //1.删除该居民id下的所有关联关系
                szxcJmTagMapper.deleteSzxcJmTagByJmId(szxcJmTags.get(0).getJmId());
                //存储所有的
                for(SzxcJmTag szxcJmTag:szxcJmTags){
                    szxcJmTagMapper.insertSzxcJmTag(szxcJmTag);
                }
            }
        } catch (Exception e) {
            result=0;
            e.printStackTrace();
        }

        return result;
    }

    /**
     * 修改居民标签关联
     *
     * @param szxcJmTag 居民标签关联
     * @return 结果
     */
    @Override
    public int updateSzxcJmTag(SzxcJmTag szxcJmTag)
    {
        return szxcJmTagMapper.updateSzxcJmTag(szxcJmTag);
    }

    /**
     * 批量删除居民标签关联
     *
     * @param ids 需要删除的居民标签关联主键
     * @return 结果
     */
    @Override
    public int deleteSzxcJmTagByIds(Long[] ids)
    {
        return szxcJmTagMapper.deleteSzxcJmTagByIds(ids);
    }

    /**
     * 删除居民标签关联信息
     *
     * @param id 居民标签关联主键
     * @return 结果
     */
    @Override
    public int deleteSzxcJmTagById(Long id)
    {
        return szxcJmTagMapper.deleteSzxcJmTagById(id);
    }
}
